# `check-distribution` Python pip package

The `check-distribution` utility is for checking the distribution of values in intermediate variables in model runs.

Gregory H. Halverson (they/them)<br>
[gregory.h.halverson@jpl.nasa.gov](mailto:gregory.h.halverson@jpl.nasa.gov)<br>
Lead developer<br>
NASA Jet Propulsion Laboratory 329G
